@@ -11,7 +11,7 @@ fn main() {
 "#;
 
     if let Ok(dom) = parsercher::parse(&doc) {
-        let mut needle = Tag::new("li".to_string());
+        let mut needle = Tag::new("li");
         needle.set_attr("class", "target");
         if let Some(tags) = parsercher::search_tag(&dom, &needle) {
             println!("{:#?}", tags);
